# Generated file. To retain edits, remove this comment.

"""itkwasm-htj2k-emscripten: Wasm-SIMD accelerated decoding and encoding of High-throughput JPEG2000 images. Emscripten implementation."""

from .decode_async import decode_async
from .encode_async import encode_async

from ._version import __version__
